==> tencent_im_sdk_mobile-0.0.1.tar.gz: lib/src/message.dart <==
import 'dart:convert';

import 'package:tencent_im_sdk_platform_interface/tencent_im_sdk_platform_interface.dart';
import 'package:tencent_im_sdk_plugin/enum/V2TimAdvancedMsgListener.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';

const int _V2TIM_ELEM_TYPE_TEXT = 1;
const int _V2TIM_ELEM_TYPE_CUSTOM = 2;
// const int _V2TIM_ELEM_TYPE_IMAGE = 3;
// const int _V2TIM_ELEM_TYPE_SOUND = 4;
// const int _V2TIM_ELEM_TYPE_VIDEO = 5;
// const int _V2TIM_ELEM_TYPE_FILE = 6;
// const int _V2TIM_ELEM_TYPE_LOCATION = 7;
// const int _V2TIM_ELEM_TYPE_FACE = 8;
// const int _V2TIM_ELEM_TYPE_GROUP_TIPS = 9;
// const int _V2TIM_ELEM_TYPE_MERGER = 10;

// TIMElementType _convertMobileElementTypeToPlatform(int type) {
//   switch (type) {
//     case _V2TIM_ELEM_TYPE_TEXT:
//       return TIMElementType.text;
//     case _V2TIM_ELEM_TYPE_CUSTOM:
//       return TIMElementType.custom;
//     case _V2TIM_ELEM_TYPE_IMAGE:
//       return TIMElementType.image;
//     case _V2TIM_ELEM_TYPE_SOUND:
//       return TIMElementType.sound;
//     case _V2TIM_ELEM_TYPE_VIDEO:
//       return TIMElementType.video;
//     case _V2TIM_ELEM_TYPE_FILE:
//       return TIMElementType.file;
//     case _V2TIM_ELEM_TYPE_LOCATION:
//       return TIMElementType.location;
//     case _V2TIM_ELEM_TYPE_FACE:
//       return TIMElementType.face;
//     case _V2TIM_ELEM_TYPE_GROUP_TIPS:
//       return TIMElementType.groupTips;
//     case _V2TIM_ELEM_TYPE_MERGER:
//       return TIMElementType.friendChange;
//   }
//   return TIMElementType.unused;
// }

const int _V2TIM_PRIORITY_HIGH = 1;
const int _V2TIM_PRIORITY_NORMAL = 2;
const int _V2TIM_PRIORITY_LOW = 3;

int _convertPlatformMessagePriorityToMobile(TIMMessagePriority priority) {
  switch (priority) {
    case TIMMessagePriority.high:
      return _V2TIM_PRIORITY_HIGH;
    case TIMMessagePriority.normal:
      return _V2TIM_PRIORITY_NORMAL;
    case TIMMessagePriority.low:
      return _V2TIM_PRIORITY_LOW;
    case TIMMessagePriority.lowest:
      return _V2TIM_PRIORITY_LOW;
  }
}

class MessageManagerMobile extends MessageManagerPlatform {
  @override
  void init() {
    TencentImSDKPlugin.v2TIMManager.getMessageManager().addAdvancedMsgListener(
      listener: V2TimAdvancedMsgListener(
        onRecvNewMessage: (V2TimMessage message) {
          MessageElement? element;
          if (message.elemType == _V2TIM_ELEM_TYPE_TEXT) {
            element = TextMessageElement(text: message.textElem?.text ?? '');
          } else if (message.elemType == _V2TIM_ELEM_TYPE_CUSTOM) {
            element = CustomMessageElement(data: base64Decode(message.customElem?.data ?? ''));
          }

          if (element != null) {
            if (message.groupID != null && message.groupID!.isNotEmpty) {
              messageStreamController.add(
                NewGroupMessageEvent(
                  message: GroupMessage(
                    groupId: message.groupID ?? '',
                    senderUserId: message.sender ?? '',
                    element: element,
                  ),
                ),
              );
            } else {
              messageStreamController.add(
                NewMessageEvent(
                  message: Message(
                    senderUserId: message.sender ?? '',
                    element: element,
                  ),
                ),
              );
            }
          }
        },
      ),
    );
  }

  @override
  Future<void> sendCustomMessage({
    required String userId,
    required List<int> data,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
    bool isExcludedFromUnreadCount = true,
  }) async {
    V2TimValueCallback<V2TimMessage> res = await TencentImSDKPlugin.v2TIMManager.getMessageManager().sendCustomMessage(
          data: base64Encode(data),
          receiver: userId,
          groupID: '',
          priority: _convertPlatformMessagePriorityToMobile(priority),
          onlineUserOnly: isOnlineUserOnly,
          isExcludedFromUnreadCount: isExcludedFromUnreadCount,
        );

    if (res.code != 0) {
      throw (SendMessageException(res.code, res.desc));
    }
  }

  @override
  Future<void> sendCustomGroupMessage({
    required String groupId,
    required List<int> data,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
    bool isExcludedFromUnreadCount = true,
  }) async {
    V2TimValueCallback<V2TimMessage> res = await TencentImSDKPlugin.v2TIMManager.getMessageManager().sendCustomMessage(
          data: base64Encode(data),
          receiver: '',
          groupID: groupId,
          priority: _convertPlatformMessagePriorityToMobile(priority),
          onlineUserOnly: isOnlineUserOnly,
          isExcludedFromUnreadCount: isExcludedFromUnreadCount,
        );

    if (res.code != 0) {
      throw (SendMessageException(res.code, res.desc));
    }
  }

  @override
  Future<void> sendTextGroupMessage({
    required String groupId,
    required String text,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
  }) async {
    V2TimValueCallback<V2TimMessage> res = await TencentImSDKPlugin.v2TIMManager.getMessageManager().sendTextMessage(
          text: text,
          receiver: '',
          groupID: groupId,
          priority: _convertPlatformMessagePriorityToMobile(priority),
          onlineUserOnly: isOnlineUserOnly,
        );

    if (res.code != 0) {
      throw (SendMessageException(res.code, res.desc));
    }
  }

  @override
  Future<void> sendTextMessage({
    required String userId,
    required String text,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
  }) async {
    V2TimValueCallback<V2TimMessage> res = await TencentImSDKPlugin.v2TIMManager.getMessageManager().sendTextMessage(
          text: text,
          receiver: userId,
          groupID: '',
          priority: _convertPlatformMessagePriorityToMobile(priority),
          onlineUserOnly: isOnlineUserOnly,
        );

    if (res.code != 0) {
      throw (SendMessageException(res.code, res.desc));
    }
  }
}

==> tencent_im_sdk_mobile-0.0.3.tar.gz: lib/src/message.dart <==
import 'dart:convert';

import 'package:tencent_im_sdk_platform_interface/tencent_im_sdk_platform_interface.dart';
import 'package:tencent_im_sdk_plugin/enum/V2TimAdvancedMsgListener.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';

const int _V2TIM_ELEM_TYPE_TEXT = 1;
const int _V2TIM_ELEM_TYPE_CUSTOM = 2;
// const int _V2TIM_ELEM_TYPE_IMAGE = 3;
// const int _V2TIM_ELEM_TYPE_SOUND = 4;
// const int _V2TIM_ELEM_TYPE_VIDEO = 5;
// const int _V2TIM_ELEM_TYPE_FILE = 6;
// const int _V2TIM_ELEM_TYPE_LOCATION = 7;
// const int _V2TIM_ELEM_TYPE_FACE = 8;
// const int _V2TIM_ELEM_TYPE_GROUP_TIPS = 9;
// const int _V2TIM_ELEM_TYPE_MERGER = 10;

// TIMElementType _convertMobileElementTypeToPlatform(int type) {
//   switch (type) {
//     case _V2TIM_ELEM_TYPE_TEXT:
//       return TIMElementType.text;
//     case _V2TIM_ELEM_TYPE_CUSTOM:
//       return TIMElementType.custom;
//     case _V2TIM_ELEM_TYPE_IMAGE:
//       return TIMElementType.image;
//     case _V2TIM_ELEM_TYPE_SOUND:
//       return TIMElementType.sound;
//     case _V2TIM_ELEM_TYPE_VIDEO:
//       return TIMElementType.video;
//     case _V2TIM_ELEM_TYPE_FILE:
//       return TIMElementType.file;
//     case _V2TIM_ELEM_TYPE_LOCATION:
//       return TIMElementType.location;
//     case _V2TIM_ELEM_TYPE_FACE:
//       return TIMElementType.face;
//     case _V2TIM_ELEM_TYPE_GROUP_TIPS:
//       return TIMElementType.groupTips;
//     case _V2TIM_ELEM_TYPE_MERGER:
//       return TIMElementType.friendChange;
//   }
//   return TIMElementType.unused;
// }

const int _V2TIM_PRIORITY_HIGH = 1;
const int _V2TIM_PRIORITY_NORMAL = 2;
const int _V2TIM_PRIORITY_LOW = 3;

int _convertPlatformMessagePriorityToMobile(TIMMessagePriority priority) {
  switch (priority) {
    case TIMMessagePriority.high:
      return _V2TIM_PRIORITY_HIGH;
    case TIMMessagePriority.normal:
      return _V2TIM_PRIORITY_NORMAL;
    case TIMMessagePriority.low:
      return _V2TIM_PRIORITY_LOW;
    case TIMMessagePriority.lowest:
      return _V2TIM_PRIORITY_LOW;
  }
}

class MessageManager extends MessageManagerPlatform {
  @override
  void init() {
    TencentImSDKPlugin.v2TIMManager.getMessageManager().addAdvancedMsgListener(
      listener: V2TimAdvancedMsgListener(
        onRecvNewMessage: (V2TimMessage message) {
          MessageElement? element;
          if (message.elemType == _V2TIM_ELEM_TYPE_TEXT) {
            element = TextMessageElement(text: message.textElem?.text ?? '');
          } else if (message.elemType == _V2TIM_ELEM_TYPE_CUSTOM) {
            element = CustomMessageElement(data: base64Decode(message.customElem?.data ?? ''));
          }

          if (element != null) {
            if (message.groupID != null && message.groupID!.isNotEmpty) {
              messageStreamController.add(
                NewGroupMessageEvent(
                  message: GroupMessage(
                    groupId: message.groupID ?? '',
                    senderUserId: message.sender ?? '',
                    element: element,
                  ),
                ),
              );
            } else {
              messageStreamController.add(
                NewMessageEvent(
                  message: Message(
                    senderUserId: message.sender ?? '',
                    element: element,
                  ),
                ),
              );
            }
          }
        },
      ),
    );
  }

  @override
  Future<void> sendCustomMessage({
    required String userId,
    required List<int> data,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
    bool isExcludedFromUnreadCount = true,
  }) async {
    V2TimValueCallback<V2TimMessage> res = await TencentImSDKPlugin.v2TIMManager.getMessageManager().sendCustomMessage(
          data: base64Encode(data),
          receiver: userId,
          groupID: '',
          priority: _convertPlatformMessagePriorityToMobile(priority),
          onlineUserOnly: isOnlineUserOnly,
          isExcludedFromUnreadCount: isExcludedFromUnreadCount,
        );

    if (res.code != 0) {
      throw (SendMessageException(res.code, res.desc));
    }
  }

  @override
  Future<void> sendCustomGroupMessage({
    required String groupId,
    required List<int> data,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
    bool isExcludedFromUnreadCount = true,
  }) async {
    V2TimValueCallback<V2TimMessage> res = await TencentImSDKPlugin.v2TIMManager.getMessageManager().sendCustomMessage(
          data: base64Encode(data),
          receiver: '',
          groupID: groupId,
          priority: _convertPlatformMessagePriorityToMobile(priority),
          onlineUserOnly: isOnlineUserOnly,
          isExcludedFromUnreadCount: isExcludedFromUnreadCount,
        );

    if (res.code != 0) {
      throw (SendMessageException(res.code, res.desc));
    }
  }

  @override
  Future<void> sendTextGroupMessage({
    required String groupId,
    required String text,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
  }) async {
    V2TimValueCallback<V2TimMessage> res = await TencentImSDKPlugin.v2TIMManager.getMessageManager().sendTextMessage(
          text: text,
          receiver: '',
          groupID: groupId,
          priority: _convertPlatformMessagePriorityToMobile(priority),
          onlineUserOnly: isOnlineUserOnly,
        );

    if (res.code != 0) {
      throw (SendMessageException(res.code, res.desc));
    }
  }

  @override
  Future<void> sendTextMessage({
    required String userId,
    required String text,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
  }) async {
    V2TimValueCallback<V2TimMessage> res = await TencentImSDKPlugin.v2TIMManager.getMessageManager().sendTextMessage(
          text: text,
          receiver: userId,
          groupID: '',
          priority: _convertPlatformMessagePriorityToMobile(priority),
          onlineUserOnly: isOnlineUserOnly,
        );

    if (res.code != 0) {
      throw (SendMessageException(res.code, res.desc));
    }
  }
}
